"use strict";

var React = require("react");

var draw = require("./draw");
var _require = require("./utils");

var toCharArr = _require.toCharArr;


var PropTypes = React.PropTypes;


var SegmentDisplay = React.createClass({
  displayName: "SegmentDisplay",
  propTypes: {
    /**
     * Pixel height for each digit
     */
    height: PropTypes.number,

    /**
     * Pixel width for each digit
     */
    width: PropTypes.number,

    /**
     * 
     *                                         Bevel Width
     *  Segment Width                             +-+
     *  + ........______________________________..... +  ......________
     *  |  \    /                                \ /  |   \  /
     *  |   \ /                                  /    +     \
     *  |    \                                 /   Segment    \
     *  |     \                              /     Interval     \
     *  +      *----------------------------*                    *-----
     *                                     +--------+  
     *                                     Segment Width
     * 
     */
    segmentWidth: PropTypes.number,
    segmentInterval: PropTypes.number,
    bevelWidth: PropTypes.number,

    /**
     * Padding between each digit.
     */
    padding: PropTypes.number,

    color: PropTypes.arrayOf(PropTypes.number),
    value: PropTypes.number },

  getDefaultProps: function () {
    return {
      width: 25,
      height: 50,
      segmentWidth: 4,
      segmentInterval: 1,
      bevelWidth: 0,
      pad: 0,
      padding: 4,
      opacity: 0.4,
      color: [255, 0, 0] };
  },

  render: function () {
    var width = this.props.width;
    var height = this.props.height;
    var value = this.props.value;
    var pad = this.props.pad;
    var color = this.props.color;
    var style = this.props.style;
    style = style || Styles.SegmentDisplay;

    return React.DOM.canvas({
      ref: "canvas",
      style: style,
      width: width * Math.max(this.digitCount(value), pad),
      height: height });
  },

  drawDigit: function (ctx, opts) {
    var width = opts.width;
    var height = opts.height;
    var pad = opts.pad;
    var value = opts.value;
    var digitCount = Math.max(this.digitCount(value), pad);
    ctx.clearRect(0, 0, width * digitCount, height);
    draw(ctx, opts, value, pad);
  },

  componentDidMount: function () {
    var context = this.refs.canvas.getDOMNode().getContext("2d");
    this.drawDigit(context, this.props);
  },

  componentDidUpdate: function () {
    var context = this.refs.canvas.getDOMNode().getContext("2d");
    this.drawDigit(context, this.props);
  },

  shouldComponentUpdate: function shouldComponentUpdate(nextProps) {
    return nextProps.value !== this.props.value;
  },

  digitCount: function digitCount(value) {
    return toCharArr(value).length;
  }
});

var Styles = {
  SegmentDisplay: {
    backgroundColor: "black"
  }
};

module.exports = SegmentDisplay;