"use strict";

var _require = require("./seven-segment-draw");

var drawFns = _require.drawFns;
var _require2 = require("./utils");

var padArr = _require2.padArr;
var toCharArr = _require2.toCharArr;
var hexToSegments = _require2.hexToSegments;
var rgba = _require2.rgba;


var DONT_CARE_CHAR = "_";
// http://en.wikipedia.org/wiki/Seven-segment_display#Displaying_letters
var HEX_ENCODINGS = {
  _: 0,
  "-": 64,
  "0": 63,
  "1": 6,
  "2": 91,
  "3": 79,
  "4": 102,
  "5": 109,
  "6": 125,
  "7": 7,
  "8": 127,
  "9": 111 };

function draw(context, config, value, pad) {
  var digits = padArr(DONT_CARE_CHAR, pad, toCharArr(value));
  digits.map(function (d, index) {
    return drawDigit(context, config, d, index);
  });
}

module.exports = draw;

function drawDigit(context, config, digit, offset) {
  var w = config.width;
  var h = config.height;
  var sw = config.segmentWidth;
  var si = config.segmentInterval;
  var bw = config.bevelWidth;
  var color = config.color;
  var opacity = config.opacity;
  var padding = config.padding;


  var br = bw / sw;
  var hex = HEX_ENCODINGS[digit.toString()];
  var segments = hexToSegments(7, hex);

  drawFns.map(function (f, index) {
    var alpha = segments[index] ? 1 : opacity;
    var x = offset * w + padding / 2;
    var y = padding / 2;
    var width = w - padding;
    var height = h - padding;

    context.fillStyle = rgba(color, alpha);
    f(context, x, y, width, height, sw, si, br);
  });
}